/**
 * Copyright 2012 Eric Wendelin
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package com.eriwen.gradle.js.tasks

import org.gradle.api.tasks.TaskAction
import org.gradle.api.tasks.SourceTask
import org.gradle.api.tasks.OutputDirectory
import javax.script.ScriptEngineManager
import javax.script.ScriptEngine
import com.eriwen.gradle.js.ResourceUtil
import org.gradle.plugins.javascript.rhino.RhinoShellExec

class QUnitTask extends SourceTask {
    private static final String QUNIT_PATH = 'qunit.zip'
    private static final String TMP_DIR = "tmp${File.separator}js"
    private static final ResourceUtil RESOURCE_UTIL = new ResourceUtil()
    private final RhinoShellExec rhino = new RhinoShellExec()

    @OutputDirectory def dest

    File getDest() {
        project.file(dest)
    }

    @TaskAction
    def run() {
        final File zipFile = RESOURCE_UTIL.extractFileToDirectory(new File(project.buildDir, TMP_DIR), QUNIT_PATH)
        final File qunitDir = RESOURCE_UTIL.extractZipFile(zipFile)
        final String workingDir = "${qunitDir.absolutePath}${File.separator}qunit"

        final List<String> args = []
        args.add("${workingDir}${File.separator}suite.js")

        rhino.scriptArgs("workingDir=${workingDir}")
        rhino.args(args)
        rhino.execute()

//        ScriptEngineManager factory = new ScriptEngineManager();
//        ScriptEngine engine = factory.getEngineByName("JavaScript");
//        engine.eval(new FileReader(new File(QUNIT_PATH)))
    }
}
